@@ -9,8 +9,6 @@ import gbp.log
 from . import context
 
 gbp.log.setup(color=False, verbose=True)
-import gbp.git
-
 
 def test_read():
     """
@@ -28,7 +26,7 @@ def test_read():
     >>> repo = gbp.git.GitRepository.create(str(repo_dir))
     >>> f = open(os.path.join(repo.path, 'foo.txt'), 'w')
     >>> content = 'al pha\\na\\nb\\nc'
-    >>> f.write('al pha\\na\\nb\\nc')
+    >>> ret = f.write('al pha\\na\\nb\\nc')
     >>> f.close()
     >>> repo.add_files(repo.path, force=True)
     >>> repo.commit_all(msg="foo")
@@ -46,6 +44,7 @@ def test_read():
     ''
     >>> gf.readline()
     ''
+    >>> gf.close()
     >>> gbp.git.vfs.GitVfs(repo, 'HEAD').open('foo.txt').read() == content
     True
     >>> gf = vfs.open('doesnotexist')
